@@ -12,7 +12,7 @@ from smof.version import __version__
 
 def to_pair(seq):
     """
-    Convert a FastaEntry object to a simple header/sequence pair 
+    Convert a FastaEntry object to a simple header/sequence pair
     """
     return (seq.header, seq.seq)
 
@@ -97,6 +97,7 @@ def clean(
     toseq=False,
     standardize=False,
     reduce_header=False,
+    delimiter="[ |]",
     mask_lowercase=False,
     mask_irregular=False,
 ):
@@ -136,7 +137,7 @@ def clean(
     for seq in gen:
 
         if reduce_header:
-            seq.header = _parse_header_firstword(seq.header, delimiter=" \t|")
+            seq.header = _parse_header_firstword(seq.header, delimiter=delimiter)
 
         if standardize:
             try:
@@ -484,6 +485,7 @@ def find_max_orf(dna, from_start=False):
 
 
 def _get_orf(dna, all_frames=False, from_start=False, translate=True):
+    dna = dna.translate(FastaEntry.ungapper).upper()
     if all_frames:
         cds_start, cds_length = find_max_orf(dna, from_start=from_start)
         if cds_start is None:
@@ -735,8 +737,8 @@ def translate_dna(dna):
     return "".join(aa)
 
 
-def _parse_header_firstword(h, delimiter=" \t"):
-    return re.sub("^([^%s]+).*" % delimiter, "\\1", h)
+def _parse_header_firstword(h, delimiter="[ \t]"):
+    return re.sub("%s.*" % delimiter, "", h)
 
 
 def _parse_header_description(h):
